%define oname		xapian-core
%define major		30
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

Summary:	Open Source Search Engine Library
Name:		xapian
Version:	1.4.26
Release:        %mkrel 1
License:	GPLv2+
Group:		Databases
URL:		https://www.xapian.org/
Source0:	https://www.oligarchy.co.uk/xapian/%{version}/%{oname}-%{version}.tar.xz
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(uuid)

%description
Xapian is an Open Source Search Engine Library, released under the
GPL. It's written in C++, with bindings to allow use from Perl,
Python, PHP, Java, Tcl, C#, and Ruby (so far!)

Xapian is a highly adaptable toolkit which allows developers to easily
add advanced indexing and search facilities to their own applications.
It supports the Probabilistic Information Retrieval model and also
supports a rich set of boolean query operators.

%files
%{_bindir}/copydatabase
%{_bindir}/quest
%{_bindir}/simpleexpand
%{_bindir}/simpleindex
%{_bindir}/simplesearch
%{_bindir}/xapian-compact
%{_bindir}/xapian-check
%{_bindir}/xapian-delve
%{_bindir}/xapian-pos
%{_bindir}/xapian-progsrv
%{_bindir}/xapian-tcpsrv
%{_bindir}/xapian-metadata
%{_bindir}/xapian-replicate
%{_bindir}/xapian-replicate-server
%{_datadir}/%{oname}/
%{_mandir}/man1/*

#--------------------------------------------------------------------

%package -n %{libname}
Summary:	Libraries for %{name}
Group:		System/Libraries

%description -n %{libname}
Libraries for %{name}.

%files -n %{libname}
%{_libdir}/libxapian.so.%{major}{,.*}
%ifarch %{ix86}
%{_libdir}/sse2/libxapian.so.%{major}{,.*}
%endif

#--------------------------------------------------------------------

%package  -n %{develname}
Summary:	Development files for %{name}
Group:		Development/Databases
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}

%description -n %{develname}
Header files for %{name}.

%files  -n %{develname}
%{_bindir}/xapian-config
%doc %{_docdir}/%{oname}/
%dir %{_includedir}/xapian
%{_includedir}/xapian/*.h
%{_includedir}/*.h
%{_datadir}/aclocal/xapian.m4
%{_libdir}/libxapian.so
%dir %{_libdir}/cmake/xapian/
%{_libdir}/cmake/xapian/xapian-config-version.cmake
%{_libdir}/cmake/xapian/xapian-config.cmake
%{_libdir}/pkgconfig/xapian-core.pc

#--------------------------------------------------------------------

%prep
%setup -qn %{oname}-%{version}
%autopatch -p1

%build

# (lm) Xapian default to using SSE2 maths on x86 (mga#15457, mga#15578)
# upstream recommends to build two versions of the library (like Debian):
# non-SSE2 installed in /usr/lib & SSE2 installed in /usr/lib/sse2
# http://trac.xapian.org/wiki/PackagingXapian

%ifarch %{ix86}
%__mkdir_p build-%{_target_cpu}
pushd build-%{_target_cpu}
CONFIGURE_TOP=.. %configure --disable-sse --disable-static
%make_build
popd

%__mkdir_p build-sse2
pushd build-sse2
CONFIGURE_TOP=.. %configure --disable-static
%make_build
popd

%else
%configure --disable-static
%make_build
%endif

%install
%ifarch %{ix86}
%make_install -C build-%{_target_cpu}

%__make -C build-sse2 DESTDIR=%{buildroot}/sse2 install
%__mkdir_p %{buildroot}%{_libdir}/sse2
mv %{buildroot}/sse2/%{_libdir}/libxapian.so.* %{buildroot}%{_libdir}/sse2
%__rm -rf %{buildroot}/sse2
%else
%make_install
%endif

# we don't want these
find %{buildroot} -name '*.la' -delete


%changelog
* Sun Aug 18 2024 daviddavid <daviddavid> 1.4.26-1.mga10
+ Revision: 2086951
- new version: 1.4.26

* Tue Sep 05 2023 daviddavid <daviddavid> 1.4.23-1.mga10
+ Revision: 1984538
- new version: 1.4.23

* Wed Mar 22 2023 ns80 <ns80> 1.4.20-2.mga9
+ Revision: 1950003
- add a patch from Debian for a security issue (mga#31706)

* Fri Aug 05 2022 luigiwalser <luigiwalser> 1.4.20-1.mga9
+ Revision: 1875444
- 1.4.20

* Sat May 07 2022 luigiwalser <luigiwalser> 1.4.19-1.mga9
+ Revision: 1856628
- 1.4.19

* Wed Mar 30 2022 umeabot <umeabot> 1.4.18-2.mga9
+ Revision: 1833564
- Mageia 9 Mass Rebuild

* Thu Apr 01 2021 daviddavid <daviddavid> 1.4.18-1.mga9
+ Revision: 1712265
- new version: 1.4.18

* Wed Oct 14 2020 luigiwalser <luigiwalser> 1.4.17-1.mga8
+ Revision: 1636018
- 1.4.17
+ pterjan <pterjan>
- Remove usage of obsolete macros (https://github.com/rpm-software-management/rpm/issues/1211)

* Fri Feb 21 2020 umeabot <umeabot> 1.4.14-2.mga8
+ Revision: 1547798
- Mageia 8 Mass Rebuild

* Mon Feb 10 2020 daviddavid <daviddavid> 1.4.14-1.mga8
+ Revision: 1488435
- new version: 1.4.14
+ wally <wally>
- replace deprecated %%configure2_5x

* Thu Oct 17 2019 daviddavid <daviddavid> 1.4.13-1.mga8
+ Revision: 1454269
- new version: 1.4.13

* Fri Oct 11 2019 daviddavid <daviddavid> 1.4.12-1.mga8
+ Revision: 1451405
- new version: 1.4.12

* Sat Jul 06 2019 daviddavid <daviddavid> 1.4.11-1.mga8
+ Revision: 1418991
- new version: 1.4.11

* Tue Feb 12 2019 daviddavid <daviddavid> 1.4.10-1.mga7
+ Revision: 1365426
- new version: 1.4.10

* Mon Nov 19 2018 daviddavid <daviddavid> 1.4.9-1.mga7
+ Revision: 1331923
- new version: 1.4.9

* Sun Sep 23 2018 umeabot <umeabot> 1.4.7-2.mga7
+ Revision: 1301796
- Mageia 7 Mass Rebuild

* Tue Aug 14 2018 daviddavid <daviddavid> 1.4.7-1.mga7
+ Revision: 1251585
- new version: 1.4.7

* Tue Jul 17 2018 daviddavid <daviddavid> 1.4.6-1.mga7
+ Revision: 1244047
- new version: 1.4.6, fixes CVE-2018-0499 (mga#23309)

* Mon Apr 16 2018 daviddavid <daviddavid> 1.4.5-1.mga7
+ Revision: 1219492
- new version: 1.4.5
- now libmajor is 30
- remove unneeded static libraries

* Mon Dec 05 2016 luigiwalser <luigiwalser> 1.2.24-1.mga6
+ Revision: 1072661
- 1.2.24

* Fri Jul 08 2016 ngompa <ngompa> 1.2.23-1.mga6
+ Revision: 1039818
- Upgrade to 1.2.23, obsolete xapian-core

* Sat Jan 02 2016 luigiwalser <luigiwalser> 1.2.22-1.mga6
+ Revision: 918476
- 1.2.22

* Thu Aug 27 2015 cjw <cjw> 1.2.12-9.mga6
+ Revision: 870113
- rebuild with gcc 5

* Fri Apr 10 2015 lmenut <lmenut> 1.2.12-8.mga5
+ Revision: 820037
- bump release to submit to core/release

* Fri Mar 27 2015 lmenut <lmenut> 1.2.12-7.mga5
+ Revision: 819320
- build non-SSE2 & SSE2 optimized xapian library on x86 (mga#15457, mga#15578)

* Wed Oct 15 2014 umeabot <umeabot> 1.2.12-6.mga5
+ Revision: 750688
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.2.12-5.mga5
+ Revision: 690539
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 1.2.12-4.mga4
+ Revision: 520361
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 1.2.12-3.mga3
+ Revision: 386414
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Oct 20 2012 malo <malo> 1.2.12-2.mga3
+ Revision: 308557
- update RPM group

* Thu Sep 13 2012 dmorgan <dmorgan> 1.2.12-1.mga3
+ Revision: 293572
- New version

* Sun Jul 17 2011 dmorgan <dmorgan> 1.2.6-2.mga2
+ Revision: 125559
- Really fix file list
- Fix file list
- la file is required here

* Sun Jul 17 2011 dmorgan <dmorgan> 1.2.6-1.mga2
+ Revision: 125528
- Fix file lists
+ ennael <ennael>
- clean spec file
- update to 1.2.6
- remove buildroot definition
- imported package xapian


* Tue Nov 06 2007 Funda Wang <fundawang@mandriva.org> 1.0.4-2mdv2008.1
+ Revision: 106458
- rebuild for new lzma

* Tue Oct 30 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.4-1mdv2008.1
+ Revision: 103796
- new version

* Sat Oct 13 2007 Funda Wang <fundawang@mandriva.org> 1.0.3-1mdv2008.1
+ Revision: 98101
- New version 1.0.3

  + Thierry Vignaud <tvignaud@mandriva.com>
    - fix man pages extension

* Sun Jul 08 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.2-1mdv2008.0
+ Revision: 49834
- own missing file
- new version
- new devel library policy

* Thu Jun 14 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.1-1mdv2008.0
+ Revision: 39396
- bump major
- new version

* Tue May 22 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.0-2mdv2008.0
+ Revision: 29711
- devel package requires library

* Fri May 18 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.0-1mdv2008.0
+ Revision: 28298
- set buildrequires on zlib-devel
- remove not needed provides
- own missing file
- obsolete older release
- bump major
- new version


* Tue Mar 06 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9.10-1mdv2007.0
+ Revision: 133906
- new version

* Tue Jan 30 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9.9-2mdv2007.1
+ Revision: 115261
- move xapian-config to the devel package
- remove rpath from binaries
- fix provides
- spec file clean

* Fri Jan 12 2007 Nicolas Lécureuil <neoclust@mandriva.org> 0.9.9-1mdv2007.1
+ Revision: 107904
- Import xapian

